@@ -4,7 +4,7 @@
 	 * Japanese language file for phpPgAdmin.
 	 * @maintainer Tadashi Jokagi [elf2000@users.sourceforge.net]
 	 *
-	 * $Id: japanese.php,v 1.9 2004/02/23 04:42:46 chriskl Exp $
+	 * $Id: japanese.php,v 1.11 2004/07/12 04:18:41 chriskl Exp $
 	 */
 
 	// Language and character set
@@ -12,6 +12,7 @@
 	$lang['appcharset'] = 'EUC-JP';
 	$lang['applocale'] = 'ja_JP';
   	$lang['appdbencoding'] = 'EUC_JP';
+	$lang['applangdir'] = 'ltr';
   
 	// Welcome  
 	$lang['strintro'] = '褦phpPgAdminء';
@@ -101,6 +102,7 @@
 	$lang['strconfirm'] = 'ǧ';
 	$lang['strexpression'] = 'ɾ';
 	$lang['strellipsis'] = '...';
+	$lang['strseparator'] = ': ';
 	$lang['strexpand'] = 'Ÿ';
 	$lang['strcollapse'] = 'Ĥ';
 	$lang['strexplain'] = '¹Ի';
@@ -118,13 +120,19 @@
 	$lang['strprocesses'] = 'ץ';
 	$lang['strsetting'] = '';
 	$lang['streditsql'] = 'SQLԽ';
+	$lang['strruntime'] = '¹Ի: %s ms';
 	$lang['strpaginate'] = 'Paginate results';
+	$lang['struploadscript'] = 'or upload an SQL script:';
 	$lang['strstarttime'] = 'ϻ';
+	$lang['strfile'] = 'ե';
+	$lang['strfileimported'] = 'ե򥤥ݡȤޤ';
 
 	// Error handling
 	$lang['strnoframes'] = 'ΥץꥱѤ뤿ˤϥե졼बѲǽʥ֥饦ɬפǤ';
 	$lang['strbadconfig'] = 'config.inc.php켰Ǥconfig.inc.php-distƺɬפޤ';
 	$lang['strnotloaded'] = 'ǡ١򥵥ݡȤ褦PHPΥѥ롦󥹥ȡ뤬Ƥޤ(ƥˤäƤphpѥå¾php-pgsqlѥåΥ󥹥ȡ롦ʤɤɬפǤ)';
+	$lang['strphpversionnotsupported'] = 'PHPΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
+	$lang['strpostgresqlversionnotsupported'] = 'PostgreSQLΥСϥݡȤƤޤ󡣥С %s ʾ˥åץ졼ɤƤ';
 	$lang['strbadschema'] = '̵Υޤꤵޤ';
 	$lang['strbadencoding'] = 'ǡ١ǥ饤ȥ󥳡ɤꤷޤǤ';
 	$lang['strsqlerror'] = 'SQL顼:';
@@ -134,6 +142,9 @@
 	$lang['strnoobjects'] = '֥ȤĤޤ';
 	$lang['strrownotunique'] = 'Υ쥳ɤˤϰռ̻Ҥޤ';
 	$lang['strnoreportsdb'] = 'ݡȥǡ١Ƥޤ󡣥ǥ쥯ȥˤINSTALLեɤǤ';
+	$lang['strnouploads'] = 'ե륢åץɤ̵Ǥ';
+	$lang['strimporterror'] = 'ݡȥ顼';
+	$lang['strimporterrorline'] = '%s ܤݡȥ顼Ǥ';
 
 	// Tables
 	$lang['strtable'] = 'ơ֥';
@@ -164,7 +175,7 @@
 	$lang['strconfdeleterow'] = 'ˤΥ쥳ɤޤ?';
 	$lang['strrowdeleted'] = '쥳ɤޤ';
 	$lang['strrowdeletedbad'] = '쥳ɤκ˼Ԥޤ';
-	$lang['strsaveandrepeat'] = '¸ȷ֤';
+	$lang['strinsertandrepeat'] = 'ȷ֤';
 	$lang['strfield'] = 'ե';
 	$lang['strfields'] = 'եɰ';
 	$lang['strnumfields'] = 'եɿ';
@@ -188,6 +199,8 @@
 	$lang['strdataonly'] = 'ǡΤ';
 	$lang['strstructureonly'] = '¤Τ';
 	$lang['strstructureanddata'] = '¤ȥǡ';
+	$lang['strtabbed'] = 'Tabbed';
+	$lang['strauto'] = 'ư';
 
 	// Users
 	$lang['struser'] = '桼';
@@ -248,7 +261,7 @@
 	$lang['strgrantfailed'] = 'øͿ˼Ԥޤ';
 	$lang['strgrantbad'] = 'ʤȤͤΥ桼롼פˡʤȤҤȤĤøꤷʤФʤޤ';
 	$lang['stralterprivs'] = 'øѹ';
-	$lang['strgrantor'] = 'Grantor';
+	$lang['strgrantor'] = 'Ϳ';
 	$lang['strasterisk'] = '*';
 
 	// Databases
@@ -271,6 +284,11 @@
 	$lang['strvacuumbad'] = 'Х塼˼Ԥޤ';
 	$lang['stranalyzegood'] = 'Ϥλޤ';
 	$lang['stranalyzebad'] = 'Ϥ˼Ԥޤ';
+	$lang['strreindexgood'] = 'ƥǥåλޤ';
+	$lang['strreindexbad'] = 'ƥǥå˼Ԥޤ';
+	$lang['strfull'] = '٤';
+	$lang['strfreeze'] = 'ե꡼';
+	$lang['strforce'] = '';
 
 	// Views
 	$lang['strview'] = 'ӥ塼';
@@ -282,6 +300,7 @@
 	$lang['strviewname'] = 'ӥ塼̾';
 	$lang['strviewneedsname'] = 'ӥ塼̾ꤷʤФʤޤ';
 	$lang['strviewneedsdef'] = '̾ꤷʤФʤޤ';
+	$lang['strviewneedsfields'] = 'You must give the columns you want selected in your view.';
 	$lang['strviewcreated'] = 'ӥ塼ޤ';
 	$lang['strviewcreatedbad'] = 'ӥ塼κ˼Ԥޤ';
 	$lang['strconfdropview'] = '˥ӥ塼%sפ˴ޤ?';
@@ -291,6 +310,7 @@
 	$lang['strviewupdatedbad'] = 'ӥ塼ι˼Ԥޤ';
 	$lang['strviewlink'] = 'Linking Keys';
 	$lang['strviewconditions'] = 'ɲþ';
+	$lang['strcreateviewwiz'] = 'ɤǥӥ塼';
 
 	// Sequences
 	$lang['strsequence'] = '';
@@ -466,6 +486,8 @@
 	$lang['strconfdropschema'] = '˥ޡ%sפ˴ޤ?';
 	$lang['strschemadropped'] = 'ޤ˴ޤ';
 	$lang['strschemadroppedbad'] = 'ޤ˴˼Ԥޤ';
+	$lang['strschemaaltered'] = 'ޤѹޤ';
+	$lang['strschemaalteredbad'] = 'ޤѹ˼Ԥޤ';
 
 	// Reports
 	$lang['strreport'] = 'ݡ';
@@ -508,13 +530,13 @@
 	$lang['strcommutator'] = 'Commutator';
 	$lang['strnegator'] = 'Negator';
 	$lang['strrestrict'] = 'Restrict';
-	$lang['strjoin'] = 'Join';
-	$lang['strhashes'] = 'Hashes';
-	$lang['strmerges'] = 'Merges';
-	$lang['strleftsort'] = 'Left sort';
-	$lang['strrightsort'] = 'Right sort';
-	$lang['strlessthan'] = 'Less than';
-	$lang['strgreaterthan'] = 'Greater than';
+	$lang['strjoin'] = '';
+	$lang['strhashes'] = 'ϥå';
+	$lang['strmerges'] = 'ʻ';
+	$lang['strleftsort'] = '';
+	$lang['strrightsort'] = '';
+	$lang['strlessthan'] = '̤';
+	$lang['strgreaterthan'] = 'ʾ';
 	$lang['stroperatorneedsname'] = '黻̾ꤹɬפޤ';
 	$lang['stroperatorcreated'] = '黻Ҥޤ';
 	$lang['stroperatorcreatedbad'] = '黻Ҥκ˼Ԥޤ';
@@ -527,9 +549,9 @@
 	$lang['strnocasts'] = '㥹ȤĤޤ';
 	$lang['strsourcetype'] = '';
 	$lang['strtargettype'] = 'åȥ';
-	$lang['strimplicit'] = 'Implicit';
+	$lang['strimplicit'] = '';
 	$lang['strinassignment'] = 'In assignment';
-	$lang['strbinarycompat'] = '(Binary compatible)';
+	$lang['strbinarycompat'] = '(Хʥߴ)';
 	
 	// Conversions
 	$lang['strconversions'] = 'Ѵ';
@@ -544,9 +566,9 @@
 	
 	// Info
 	$lang['strnoinfo'] = 'ͭʾ󤬤ޤ';
-	$lang['strreferringtables'] = 'Referring tables';
-	$lang['strparenttables'] = 'Parent tables';
-	$lang['strchildtables'] = 'Child tables';
+	$lang['strreferringtables'] = 'ȥơ֥';
+	$lang['strparenttables'] = 'ƥơ֥';
+	$lang['strchildtables'] = 'ҥơ֥';
 
 	// Aggregates
 	$lang['straggregates'] = 'װ';
