@@ -4,7 +4,7 @@
 	 * Japanese language file for phpPgAdmin.
 	 * @maintainer Tadashi Jokagi [elf2000@users.sourceforge.net]
 	 *
-	 * $Id: japanese.php,v 1.9 2004/02/23 04:42:46 chriskl Exp $
+	 * $Id: japanese.php,v 1.11 2004/07/12 04:18:42 chriskl Exp $
 	 */
 
 	// Language and character set
@@ -12,6 +12,7 @@
 	$lang['appcharset'] = 'EUC-JP';
 	$lang['applocale'] = 'ja_JP';
   	$lang['appdbencoding'] = 'EUC_JP';
+	$lang['applangdir'] = 'ltr';
   
 	// Welcome  
 	$lang['strintro'] = '&#12424;&#12358;&#12371;&#12381;phpPgAdmin&#12408;&#12290;';
@@ -101,6 +102,7 @@
 	$lang['strconfirm'] = '&#30906;&#35469;';
 	$lang['strexpression'] = '&#35413;&#20385;&#24335;';
 	$lang['strellipsis'] = '...';
+	$lang['strseparator'] = ': ';
 	$lang['strexpand'] = '&#23637;&#38283;';
 	$lang['strcollapse'] = '&#38281;&#12376;&#12427;';
 	$lang['strexplain'] = '&#23455;&#34892;&#26178;&#38291;';
@@ -118,13 +120,19 @@
 	$lang['strprocesses'] = '&#12503;&#12525;&#12475;&#12473;&#19968;&#35239;';
 	$lang['strsetting'] = '&#35373;&#23450;';
 	$lang['streditsql'] = 'SQL&#32232;&#38598;';
+	$lang['strruntime'] = '&#32207;&#23455;&#34892;&#26178;&#38291;: %s ms';
 	$lang['strpaginate'] = 'Paginate results';
+	$lang['struploadscript'] = 'or upload an SQL script:';
 	$lang['strstarttime'] = '&#38283;&#22987;&#26178;&#38291;';
+	$lang['strfile'] = '&#12501;&#12449;&#12452;&#12523;';
+	$lang['strfileimported'] = '&#12501;&#12449;&#12452;&#12523;&#12434;&#12452;&#12531;&#12509;&#12540;&#12488;&#12375;&#12414;&#12375;&#12383;&#12290;';
 
 	// Error handling
 	$lang['strnoframes'] = '&#12371;&#12398;&#12450;&#12503;&#12522;&#12465;&#12540;&#12471;&#12519;&#12531;&#12434;&#20351;&#29992;&#12377;&#12427;&#12383;&#12417;&#12395;&#12399;&#12501;&#12524;&#12540;&#12512;&#12364;&#20351;&#29992;&#21487;&#33021;&#12394;&#12502;&#12521;&#12454;&#12470;&#12540;&#12364;&#24517;&#35201;&#12391;&#12377;&#12290;';
 	$lang['strbadconfig'] = 'config.inc.php&#12364;&#26087;&#24335;&#12391;&#12377;&#12290;&#26032;&#12375;&#12356;config.inc.php-dist&#12363;&#12425;&#20877;&#20316;&#25104;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
 	$lang['strnotloaded'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12434;&#12469;&#12509;&#12540;&#12488;&#12377;&#12427;&#12424;&#12358;&#12395;PHP&#12398;&#12467;&#12531;&#12497;&#12452;&#12523;&#12539;&#12452;&#12531;&#12473;&#12488;&#12540;&#12523;&#12364;&#12373;&#12428;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;(&#12471;&#12473;&#12486;&#12512;&#12395;&#12424;&#12387;&#12390;&#12399;php&#12497;&#12483;&#12465;&#12540;&#12472;&#12398;&#20182;&#12395;php-pgsql&#12497;&#12483;&#12465;&#12540;&#12472;&#12398;&#12452;&#12531;&#12473;&#12488;&#12540;&#12523;&#12539;&#35373;&#23450;&#12394;&#12393;&#12364;&#24517;&#35201;&#12391;&#12377;)';
+	$lang['strphpversionnotsupported'] = '&#12371;&#12398;PHP&#12398;&#12496;&#12540;&#12472;&#12519;&#12531;&#12399;&#12469;&#12509;&#12540;&#12488;&#12375;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12496;&#12540;&#12472;&#12519;&#12531; %s &#20197;&#19978;&#12395;&#12450;&#12483;&#12503;&#12464;&#12524;&#12540;&#12489;&#12375;&#12390;&#12367;&#12384;&#12373;&#12356;&#12290;';
+	$lang['strpostgresqlversionnotsupported'] = '&#12371;&#12398;PostgreSQL&#12398;&#12496;&#12540;&#12472;&#12519;&#12531;&#12399;&#12469;&#12509;&#12540;&#12488;&#12375;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12496;&#12540;&#12472;&#12519;&#12531; %s &#20197;&#19978;&#12395;&#12450;&#12483;&#12503;&#12464;&#12524;&#12540;&#12489;&#12375;&#12390;&#12367;&#12384;&#12373;&#12356;&#12290;';
 	$lang['strbadschema'] = '&#28961;&#21177;&#12398;&#12473;&#12461;&#12540;&#12510;&#12364;&#25351;&#23450;&#12373;&#12428;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strbadencoding'] = '&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12398;&#20013;&#12391;&#12463;&#12521;&#12452;&#12450;&#12531;&#12488;&#12456;&#12531;&#12467;&#12540;&#12489;&#12434;&#25351;&#23450;&#12375;&#12414;&#12379;&#12435;&#12391;&#12375;&#12383;&#12290;';
 	$lang['strsqlerror'] = 'SQL&#12456;&#12521;&#12540;:';
@@ -134,6 +142,9 @@
 	$lang['strnoobjects'] = '&#12458;&#12502;&#12472;&#12455;&#12463;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strrownotunique'] = '&#12371;&#12398;&#12524;&#12467;&#12540;&#12489;&#12395;&#12399;&#19968;&#24847;&#35672;&#21029;&#23376;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strnoreportsdb'] = '&#12524;&#12509;&#12540;&#12488;&#12487;&#12540;&#12479;&#12505;&#12540;&#12473;&#12364;&#20316;&#25104;&#12373;&#12428;&#12390;&#12356;&#12414;&#12379;&#12435;&#12290;&#12487;&#12451;&#12524;&#12463;&#12488;&#12522;&#12395;&#12354;&#12427;INSTALL&#12501;&#12449;&#12452;&#12523;&#12434;&#35501;&#12435;&#12391;&#12367;&#12384;&#12373;&#12356;&#12290;';
+	$lang['strnouploads'] = '&#12501;&#12449;&#12452;&#12523;&#12450;&#12483;&#12503;&#12525;&#12540;&#12489;&#12364;&#28961;&#21177;&#12391;&#12377;&#12290;';
+	$lang['strimporterror'] = '&#12452;&#12531;&#12509;&#12540;&#12488;&#12456;&#12521;&#12540;';
+	$lang['strimporterrorline'] = '%s &#34892;&#30446;&#12364;&#12452;&#12531;&#12509;&#12540;&#12488;&#12456;&#12521;&#12540;&#12391;&#12377;&#12290;';
 
 	// Tables
 	$lang['strtable'] = '&#12486;&#12540;&#12502;&#12523;';
@@ -164,7 +175,7 @@
 	$lang['strconfdeleterow'] = '&#26412;&#24403;&#12395;&#12371;&#12398;&#12524;&#12467;&#12540;&#12489;&#12434;&#21066;&#38500;&#12375;&#12414;&#12377;&#12363;?';
 	$lang['strrowdeleted'] = '&#12524;&#12467;&#12540;&#12489;&#12434;&#21066;&#38500;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strrowdeletedbad'] = '&#12524;&#12467;&#12540;&#12489;&#12398;&#21066;&#38500;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
-	$lang['strsaveandrepeat'] = '&#20445;&#23384;&#12392;&#32368;&#12426;&#36820;&#12375;';
+	$lang['strinsertandrepeat'] = '&#25407;&#20837;&#12392;&#32368;&#12426;&#36820;&#12375;';
 	$lang['strfield'] = '&#12501;&#12451;&#12540;&#12523;&#12489;';
 	$lang['strfields'] = '&#12501;&#12451;&#12540;&#12523;&#12489;&#19968;&#35239;';
 	$lang['strnumfields'] = '&#12501;&#12451;&#12540;&#12523;&#12489;&#25968;';
@@ -188,6 +199,8 @@
 	$lang['strdataonly'] = '&#12487;&#12540;&#12479;&#12398;&#12415;';
 	$lang['strstructureonly'] = '&#27083;&#36896;&#12398;&#12415;';
 	$lang['strstructureanddata'] = '&#27083;&#36896;&#12392;&#12487;&#12540;&#12479;';
+	$lang['strtabbed'] = 'Tabbed';
+	$lang['strauto'] = '&#33258;&#21205;';
 
 	// Users
 	$lang['struser'] = '&#12518;&#12540;&#12470;&#12540;';
@@ -248,7 +261,7 @@
 	$lang['strgrantfailed'] = '&#29305;&#27177;&#12434;&#19982;&#12360;&#12427;&#20107;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strgrantbad'] = '&#23569;&#12394;&#12367;&#12392;&#12418;&#19968;&#20154;&#12398;&#12518;&#12540;&#12470;&#12540;&#12363;&#12464;&#12523;&#12540;&#12503;&#12395;&#12289;&#23569;&#12394;&#12367;&#12392;&#12418;&#12402;&#12392;&#12388;&#12398;&#29305;&#27177;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['stralterprivs'] = '&#29305;&#27177;&#12398;&#22793;&#26356;';
-	$lang['strgrantor'] = 'Grantor';
+	$lang['strgrantor'] = '&#35698;&#19982;';
 	$lang['strasterisk'] = '*';
 
 	// Databases
@@ -271,6 +284,11 @@
 	$lang['strvacuumbad'] = '&#12496;&#12461;&#12517;&#12540;&#12512;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['stranalyzegood'] = '&#35299;&#26512;&#12434;&#23436;&#20102;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['stranalyzebad'] = '&#35299;&#26512;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strreindexgood'] = '&#20877;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12434;&#23436;&#20102;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strreindexbad'] = '&#20877;&#12452;&#12531;&#12487;&#12483;&#12463;&#12473;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strfull'] = '&#12377;&#12409;&#12390;';
+	$lang['strfreeze'] = '&#12501;&#12522;&#12540;&#12474;';
+	$lang['strforce'] = '&#24375;&#21046;';
 
 	// Views
 	$lang['strview'] = '&#12499;&#12517;&#12540;';
@@ -282,6 +300,7 @@
 	$lang['strviewname'] = '&#12499;&#12517;&#12540;&#21517;';
 	$lang['strviewneedsname'] = '&#12499;&#12517;&#12540;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strviewneedsdef'] = '&#23450;&#32681;&#21517;&#12434;&#25351;&#23450;&#12375;&#12394;&#12369;&#12428;&#12400;&#12394;&#12426;&#12414;&#12379;&#12435;&#12290;';
+	$lang['strviewneedsfields'] = 'You must give the columns you want selected in your view.';
 	$lang['strviewcreated'] = '&#12499;&#12517;&#12540;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strviewcreatedbad'] = '&#12499;&#12517;&#12540;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strconfdropview'] = '&#26412;&#24403;&#12395;&#12499;&#12517;&#12540;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
@@ -291,6 +310,7 @@
 	$lang['strviewupdatedbad'] = '&#12499;&#12517;&#12540;&#12398;&#26356;&#26032;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strviewlink'] = 'Linking Keys';
 	$lang['strviewconditions'] = '&#36861;&#21152;&#26465;&#20214;';
+	$lang['strcreateviewwiz'] = '&#12454;&#12451;&#12470;&#12540;&#12489;&#12391;&#12499;&#12517;&#12540;&#12434;&#20316;&#25104;&#12377;&#12427;';
 
 	// Sequences
 	$lang['strsequence'] = '&#12471;&#12540;&#12465;&#12531;&#12473;';
@@ -466,6 +486,8 @@
 	$lang['strconfdropschema'] = '&#26412;&#24403;&#12395;&#12473;&#12461;&#12540;&#12510;&#12300;%s&#12301;&#12434;&#30772;&#26820;&#12375;&#12414;&#12377;&#12363;?';
 	$lang['strschemadropped'] = '&#12473;&#12461;&#12540;&#12510;&#12434;&#30772;&#26820;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['strschemadroppedbad'] = '&#12473;&#12461;&#12540;&#12510;&#12398;&#30772;&#26820;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strschemaaltered'] = '&#12473;&#12461;&#12540;&#12510;&#12434;&#22793;&#26356;&#12375;&#12414;&#12375;&#12383;&#12290;';
+	$lang['strschemaalteredbad'] = '&#12473;&#12461;&#12540;&#12510;&#12398;&#22793;&#26356;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
 
 	// Reports
 	$lang['strreport'] = '&#12524;&#12509;&#12540;&#12488;';
@@ -508,13 +530,13 @@
 	$lang['strcommutator'] = 'Commutator';
 	$lang['strnegator'] = 'Negator';
 	$lang['strrestrict'] = 'Restrict';
-	$lang['strjoin'] = 'Join';
-	$lang['strhashes'] = 'Hashes';
-	$lang['strmerges'] = 'Merges';
-	$lang['strleftsort'] = 'Left sort';
-	$lang['strrightsort'] = 'Right sort';
-	$lang['strlessthan'] = 'Less than';
-	$lang['strgreaterthan'] = 'Greater than';
+	$lang['strjoin'] = '&#32080;&#21512;';
+	$lang['strhashes'] = '&#12495;&#12483;&#12471;&#12517;';
+	$lang['strmerges'] = '&#20341;&#21512;';
+	$lang['strleftsort'] = '&#24038;&#12477;&#12540;&#12488;';
+	$lang['strrightsort'] = '&#21491;&#12477;&#12540;&#12488;';
+	$lang['strlessthan'] = '&#26410;&#28288;';
+	$lang['strgreaterthan'] = '&#20197;&#19978;';
 	$lang['stroperatorneedsname'] = '&#28436;&#31639;&#23376;&#21517;&#12434;&#25351;&#23450;&#12377;&#12427;&#24517;&#35201;&#12364;&#12354;&#12426;&#12414;&#12377;&#12290;';
 	$lang['stroperatorcreated'] = '&#28436;&#31639;&#23376;&#12434;&#20316;&#25104;&#12375;&#12414;&#12375;&#12383;&#12290;';
 	$lang['stroperatorcreatedbad'] = '&#28436;&#31639;&#23376;&#12398;&#20316;&#25104;&#12395;&#22833;&#25943;&#12375;&#12414;&#12375;&#12383;&#12290;';
@@ -527,9 +549,9 @@
 	$lang['strnocasts'] = '&#12461;&#12515;&#12473;&#12488;&#12364;&#35211;&#12388;&#12363;&#12426;&#12414;&#12379;&#12435;&#12290;';
 	$lang['strsourcetype'] = '&#12477;&#12540;&#12473;&#12479;&#12452;&#12503;';
 	$lang['strtargettype'] = '&#12479;&#12540;&#12466;&#12483;&#12488;&#12479;&#12452;&#12503;';
-	$lang['strimplicit'] = 'Implicit';
+	$lang['strimplicit'] = '&#26263;&#40665;';
 	$lang['strinassignment'] = 'In assignment';
-	$lang['strbinarycompat'] = '(Binary compatible)';
+	$lang['strbinarycompat'] = '(&#12496;&#12452;&#12490;&#12522;&#20114;&#25563;)';
 	
 	// Conversions
 	$lang['strconversions'] = '&#22793;&#25563;&#19968;&#35239;';
@@ -544,9 +566,9 @@
 	
 	// Info
 	$lang['strnoinfo'] = '&#26377;&#21177;&#12394;&#24773;&#22577;&#12364;&#12354;&#12426;&#12414;&#12379;&#12435;&#12290;';
-	$lang['strreferringtables'] = 'Referring tables';
-	$lang['strparenttables'] = 'Parent tables';
-	$lang['strchildtables'] = 'Child tables';
+	$lang['strreferringtables'] = '&#21442;&#29031;&#12486;&#12540;&#12502;&#12523;&#19968;&#35239;';
+	$lang['strparenttables'] = '&#35242;&#12486;&#12540;&#12502;&#12523;&#19968;&#35239;';
+	$lang['strchildtables'] = '&#23376;&#12486;&#12540;&#12502;&#12523;&#19968;&#35239;';
 
 	// Aggregates
 	$lang['straggregates'] = '&#38598;&#35336;&#19968;&#35239;';
